from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Location import Location

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Classroom(Location):
    __type__ = ONTOIM["Classroom"]

    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, Union

from ontopia_py.l0.Activity import Activity

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Feature import Feature
    from ontopia_py.cpv.Family import Family
    from ontopia_py.cpv.Person import Person
    from ontopia_py.ti.TemporalEntity import TemporalEntity
    from rdflib import Graph, Literal


class DemographicObservation(Activity):
    __type__ = ONTOIM["DemographicObservation"]

    hasTemporalEntity: TemporalEntity = None
    hasDemographicReference: Union(Person, Family) = None
    hasSpatialCoverage: Feature = None
    observationValue: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasTemporalEntity:
            g.add(
                (self.uriRef, ONTOIM["hasTemporalEntity"], self.hasTemporalEntity.uriRef))

        if self.hasDemographicReference:
            g.add((self.uriRef, ONTOIM["hasDemographicReference"],
                  self.hasDemographicReference.uriRef))

        if self.hasSpatialCoverage:
            g.add(
                (self.uriRef, CLV["hasSpatialCoverage"], self.hasSpatialCoverage.uriRef))

        if self.observationValue:
            g.add(
                (self.uriRef, ONTOIM["observationValue"], self.observationValue))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Classroom import Classroom

if TYPE_CHECKING:
    from ontopia_py.clv.Address import Address
    from rdflib import Graph


class PhysicalClassroom(Classroom):
    __type__ = ONTOIM["PhysicalClassroom"]

    hasAddress: Address = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAddress:
            g.add((self.uriRef, ONTOIM["hasAddress"], self.hasAddress.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ontopia_py.iot.RoadSegment import RoadSegment

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.StreetToponym import StreetToponym
    from rdflib import Graph


class RoadSegment(RoadSegment):
    __type__ = ONTOIM["RoadSegment"]

    hasStreetToponym: StreetToponym = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasStreetToponym:
            g.add(
                (self.uriRef, CLV["hasStreetToponym"], self.hasStreetToponym.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Facility import Facility

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Course import Course
    from .SchoolType import SchoolType
    from .Subscriber import Subscriber
    from .Subscribers import Subscribers


class School(Facility):
    __type__ = ONTOIM["School"]

    hasSchoolType: List[SchoolType] = None
    hasSubscribers: List[Subscribers] = None
    hasSubscription: List[Subscriber] = None
    providesCourse: List[Course] = None
    schoolCode: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasSchoolType:
            for hasSchoolType in self.hasSchoolType:
                g.add(
                    (self.uriRef, ONTOIM["hasSchoolType"], hasSchoolType.uriRef))

        if self.hasSubscribers:
            for hasSubscribers in self.hasSubscribers:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscribers"], hasSubscribers.uriRef))

        if self.hasSubscription:
            for hasSubscription in self.hasSubscription:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscription"], hasSubscription.uriRef))

        if self.providesCourse:
            for providesCourse in self.providesCourse:
                g.add(
                    (self.uriRef, ONTOIM["providesCourse"], providesCourse.uriRef))

        if self.schoolCode:
            g.add((self.uriRef, ONTOIM["schoolCode"], self.schoolCode))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .DemographicObservation import DemographicObservation

if TYPE_CHECKING:
    from rdflib import Graph

    from .CivilStatusCategory import CivilStatusCategory


class CivilStatus(DemographicObservation):
    __type__ = ONTOIM["CivilStatus"]

    hasCivilStatusCategory: CivilStatusCategory = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCivilStatusCategory:
            g.add(
                (self.uriRef, ONTOIM["hasCivilStatusCategory"], self.hasCivilStatusCategory.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Facility import Facility

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .HospitalDepartment import HospitalDepartment


class Heritage(Facility):
    __type__ = ONTOIM["Heritage"]

    hasHospitalDepartment: List[HospitalDepartment] = None
    totalNumberOfBeds: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasHospitalDepartment:
            for hasHospitalDepartment in self.hasHospitalDepartment:
                g.add(
                    (self.uriRef, ONTOIM["hasHospitalDepartment"], hasHospitalDepartment.uriRef))

        if self.totalNumberOfBeds:
            g.add(
                (self.uriRef, ONTOIM["totalNumberOfBeds"], self.totalNumberOfBeds))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .PrivateOrganization import PrivateOrganization

if TYPE_CHECKING:
    from ontopia_py.cpv.Person import Person
    from rdflib import Graph, Literal

    from .AssociationCategory import AssociationCategory
    from .Members import Members
    from .Subscriber import Subscriber


class Association(PrivateOrganization):
    __type__ = ONTOIM["Association"]

    hasAssociationCategory: List[AssociationCategory] = None
    hasMembers: List[Members] = None
    hasReferent: List[Person] = None
    hasSubscription: List[Subscriber] = None
    associationRegisterCode: Literal = None
    associationRegistrationDate: Literal = None
    associationRemovalFromRegisterDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAssociationCategory:
            for hasAssociationCategory in self.hasAssociationCategory:
                g.add(
                    (self.uriRef, ONTOIM["hasAssociationCategory"], hasAssociationCategory.uriRef))

        if self.hasMembers:
            for hasMembers in self.hasMembers:
                g.add(
                    (self.uriRef, ONTOIM["hasMembers"], hasMembers.uriRef))

        if self.hasReferent:
            for hasReferent in self.hasReferent:
                g.add(
                    (self.uriRef, ONTOIM["hasReferent"], hasReferent.uriRef))

        if self.hasSubscription:
            for hasSubscription in self.hasSubscription:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscription"], hasSubscription.uriRef))

        if self.associationRegisterCode:
            g.add(
                (self.uriRef, ONTOIM["associationRegisterCode"], self.associationRegisterCode))

        if self.associationRegistrationDate:
            g.add(
                (self.uriRef, ONTOIM["associationRegistrationDate"], self.associationRegistrationDate))

        if self.associationRemovalFromRegisterDate:
            g.add(
                (self.uriRef, ONTOIM["associationRemovalFromRegisterDate"], self.associationRemovalFromRegisterDate))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .PrivateOrganization import PrivateOrganization

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class ArtisanOrganization(PrivateOrganization):
    __type__ = ONTOIM["ArtisanOrganization"]

    artisanRegisterCode: Literal = None
    artisanRegistrationDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.artisanRegisterCode:
            g.add(
                (self.uriRef, ONTOIM["artisanRegisterCode"], self.artisanRegisterCode))

        if self.artisanRegistrationDate:
            g.add(
                (self.uriRef, ONTOIM["artisanRegistrationDate"], self.artisanRegistrationDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Collection import Collection

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Facility import Facility
    from .HeritageType import HeritageType


class Heritage(Collection):
    __type__ = ONTOIM["Heritage"]

    hasFacility: List[Facility] = None
    hasHeritageType: List[HeritageType] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasFacility:
            for hasFacility in self.hasFacility:
                g.add((self.uriRef, ONTOIM["hasFacility"], hasFacility.uriRef))

        if self.hasHeritageType:
            g.add(
                (self.uriRef, ONTOIM["hasHeritageType"], self.hasHeritageType.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Object import Object

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Country import Country
    from ontopia_py.mu.Value import Value
    from rdflib import Graph, Literal

    from .VehicleCategory import VehicleCategory


class Vehicle(Object):
    __type__ = ONTOIM["Vehicle"]

    hasEngineDisplacement: List[Value] = None
    hasHeight: List[Value] = None
    hasLength: List[Value] = None
    hasWeight: List[Value] = None
    hasWidth: List[Value] = None
    hasVehicleCategory: VehicleCategory = None
    hasRegistrationCountry: Country = None
    brand: List[Literal] = None
    color: List[Literal] = None
    model: List[Literal] = None
    licensePlate: Literal = None
    registrationYear: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEngineDisplacement:
            for hasEngineDisplacement in self.hasEngineDisplacement:
                g.add(
                    (self.uriRef, ONTOIM["hasEngineDisplacement"], hasEngineDisplacement.uriRef))

        if self.hasHeight:
            for hasHeight in self.hasHeight:
                g.add((self.uriRef, ONTOIM["hasHeight"], hasHeight.uriRef))

        if self.hasLength:
            for hasLength in self.hasLength:
                g.add((self.uriRef, ONTOIM["hasLength"], hasLength.uriRef))

        if self.hasWeight:
            for hasWeight in self.hasWeight:
                g.add((self.uriRef, ONTOIM["hasWeight"], hasWeight.uriRef))

        if self.hasWidth:
            for hasWidth in self.hasWidth:
                g.add((self.uriRef, ONTOIM["hasWidth"], hasWidth.uriRef))

        if self.hasVehicleCategory:
            g.add(
                (self.uriRef, ONTOIM["hasVehicleCategory"], self.hasVehicleCategory.uriRef))

        if self.hasRegistrationCountry:
            g.add(
                (self.uriRef, ONTOIM["hasRegistrationCountry"], self.hasRegistrationCountry.uriRef))

        if self.brand:
            for brand in self.brand:
                g.add((self.uriRef, ONTOIM["brand"], brand))

        if self.color:
            for color in self.color:
                g.add((self.uriRef, ONTOIM["color"], color))

        if self.model:
            for model in self.model:
                g.add((self.uriRef, ONTOIM["model"], model))

        if self.licensePlate:
            g.add((self.uriRef, ONTOIM["licensePlate"], self.licensePlate))

        if self.registrationYear:
            g.add(
                (self.uriRef, ONTOIM["registrationYear"], self.registrationYear))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.cov.PrivateOrganization import PrivateOrganization

from ..ns import *
from .Organization import Organization

if TYPE_CHECKING:
    from rdflib import Graph

    from .CompanyDemographicCategory import CompanyDemographicCategory
    from .OrganizationSection import OrganizationSection


class PrivateOrganization(Organization, PrivateOrganization):
    __type__ = ONTOIM["PrivateOrganization"]

    hasDemographicCategory: List[CompanyDemographicCategory] = None
    hasOrganizationSection: List[OrganizationSection] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasDemographicCategory:
            for hasDemographicCategory in self.hasDemographicCategory:
                g.add(
                    (self.uriRef, ONTOIM["hasDemographicCategory"], hasDemographicCategory.uriRef))

        if self.hasOrganizationSection:
            for hasOrganizationSection in self.hasOrganizationSection:
                g.add(
                    (self.uriRef, ONTOIM["hasOrganizationSection"], hasOrganizationSection.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Facility import Facility

if TYPE_CHECKING:
    from ontopia_py.mu.Value import Value
    from rdflib import Graph

    from .Plant import Plant


class GreenZone(Facility):
    __type__ = ONTOIM["GreenZone"]

    hasPlant: List[Plant] = None
    hasSurface: List[Value] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasPlant:
            for hasPlant in self.hasPlant:
                g.add((self.uriRef, ONTOIM["hasPlant"], hasPlant.uriRef))

        if self.hasSurface:
            for hasSurface in self.hasSurface:
                g.add((self.uriRef, ONTOIM["hasSurface"], hasSurface.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.poi.MultiplePointOfInterest import MultiplePointOfInterest

from ..ns import *
from .School import School

if TYPE_CHECKING:
    from rdflib import Graph


class ComprehensiveInstitute(School, MultiplePointOfInterest):
    __type__ = ONTOIM["ComprehensiveInstitute"]

    includesSchool: List[School] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.includesSchool:
            for includesSchool in self.includesSchool:
                g.add(
                    (self.uriRef, ONTOIM["includesSchool"], includesSchool.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.poi.PointOfInterest import PointOfInterest

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .RoadSignalType import RoadSignalType


class RoadSignal(PointOfInterest):
    __type__ = ONTOIM["RoadSignal"]

    hasRoadSignalType: RoadSignalType = None
    signalValue: List[Literal] = None
    installationDate: Literal = None
    removalDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasRoadSignalType:
            g.add(
                (self.uriRef, ONTOIM["hasRoadSignalType"], self.hasRoadSignalType.uriRef))

        if self.signalValue:
            for signalValue in self.signalValue:
                g.add((self.uriRef, ONTOIM["signalValue"], signalValue))

        if self.installationDate:
            g.add(
                (self.uriRef, ONTOIM["installationDate"], self.installationDate))

        if self.removalDate:
            g.add((self.uriRef, ONTOIM["removalDate"], self.removalDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.cov.Organization import Organization

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Address import Address
    from rdflib import Graph, Literal

    from .Employees import Employees
    from .Heritage import Heritage


class Organization(Organization):
    __type__ = ONTOIM["Organization"]

    hasEmployees: List[Employees] = None
    hasHeritage: List[Heritage] = None
    hasLocalUnitAddress: List[Address] = None
    endActivityDate: Literal = None
    liquidationDate: Literal = None
    bankruptcyDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEmployees:
            for hasEmployees in self.hasEmployees:
                g.add(
                    (self.uriRef, ONTOIM["hasEmployees"], hasEmployees.uriRef))

        if self.hasHeritage:
            for hasHeritage in self.hasHeritage:
                g.add((self.uriRef, ONTOIM["hasHeritage"], hasHeritage.uriRef))

        if self.hasLocalUnitAddress:
            for hasLocalUnitAddress in self.hasLocalUnitAddress:
                g.add(
                    (self.uriRef, ONTOIM["hasLocalUnitAddress"], hasLocalUnitAddress.uriRef))

        if self.providesService:
            for providesService in self.providesService:
                g.add(
                    (self.uriRef, ONTOIM["providesService"], providesService.uriRef))

        if self.endActivityDate:
            g.add(
                (self.uriRef, ONTOIM["endActivityDate"], self.endActivityDate))

        if self.liquidationDate:
            g.add(
                (self.uriRef, ONTOIM["liquidationDate"], self.liquidationDate))

        if self.bankruptcyDate:
            g.add(
                (self.uriRef, ONTOIM["bankruptcyDate"], self.bankruptcyDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.acco.Accommodation import Accommodation

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Booking import Booking
    from .Bookings import Bookings


class Accommodation(Accommodation):
    __type__ = ONTOIM["Accommodation"]

    hasBooking: List[Booking] = None
    hasBookings: List[Bookings] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasBooking:
            for hasBooking in self.hasBooking:
                g.add((self.uriRef, ONTOIM["hasBooking"], hasBooking.uriRef))

        if self.hasBookings:
            for hasBookings in self.hasBookings:
                g.add((self.uriRef, ONTOIM["hasBookings"], hasBookings.uriRef))



from __future__ import annotations

from ontopia_py.l0.Characteristic import Characteristic

from ..ns import *


class AccidentCircumstance(Characteristic):
    __type__ = ONTOIM["AccidentCircumstance"]



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Classroom import Classroom

if TYPE_CHECKING:
    from rdflib import Graph

    from .VideoCommunicationService import VideoCommunicationService


class VirtualClassroom(Classroom):
    __type__ = ONTOIM["VirtualClassroom"]

    usesVideoCommunicationService: List[VideoCommunicationService] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.usesVideoCommunicationService:
            for usesVideoCommunicationService in self.usesVideoCommunicationService:
                g.add(
                    (self.uriRef, ONTOIM["usesVideoCommunicationService"], usesVideoCommunicationService.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.poi.PointOfInterest import PointOfInterest

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.acco.OSDFeature import OSDFeature
    from ontopia_py.cov.Organization import Organization
    from ontopia_py.publiccontract.Procedure import Procedure
    from ontopia_py.sm.OnlineContactPoint import OnlineContactPoint
    from ontopia_py.sm.PhysicalContactPoint import PhysicalContactPoint
    from rdflib import Graph

    from .CadastralData import CadastralData


class Facility(PointOfInterest):
    __type__ = ONTOIM["Facility"]

    hasOfferedService: List[OSDFeature] = None
    concessedWithProcedure: List[Procedure] = None
    ownedBy: List[Organization] = None
    hasCadastralData: CadastralData = None
    hasOnlineContactPoint: OnlineContactPoint = None
    hasPhysicalContactPoint: PhysicalContactPoint = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasOfferedService:
            for hasOfferedService in self.hasOfferedService:
                g.add(
                    (self.uriRef, ONTOIM["hasOfferedService"], hasOfferedService.uriRef))

        if self.concessedWithProcedure:
            for concessedWithProcedure in self.concessedWithProcedure:
                g.add(
                    (self.uriRef, ONTOIM["concessedWithProcedure"], concessedWithProcedure.uriRef))

        if self.ownedBy:
            for ownedBy in self.ownedBy:
                g.add((self.uriRef, ONTOIM["ownedBy"], ownedBy.uriRef))

        if self.hasCadastralData:
            g.add(
                (self.uriRef, ONTOIM["hasCadastralData"], self.hasCadastralData.uriRef))

        if self.hasOnlineContactPoint:
            g.add(
                (self.uriRef, SM["hasOnlineContactPoint"], self.hasOnlineContactPoint.uriRef))

        if self.hasPhysicalContactPoint:
            g.add(
                (self.uriRef, SM["hasPhysicalContactPoint"], self.hasPhysicalContactPoint.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Location import Location

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Address import Address
    from rdflib import Graph, Literal

    from .PavementType import PavementType
    from .RoadbedStatus import RoadbedStatus
    from .RoadCategory import RoadCategory
    from .RoadContext import RoadContext
    from .RoadSignalPresence import RoadSignalPresence
    from .RoadType import RoadType


class Road(Location):
    __type__ = ONTOIM["Road"]

    hasAddress: Address = None
    hasPavementType: PavementType = None
    hasRoadCategory: RoadCategory = None
    hasRoadContext: RoadContext = None
    hasRoadSignalPresence: RoadSignalPresence = None
    hasRoadType: RoadType = None
    hasRoadbedStatus: RoadbedStatus = None
    roadName: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAddress:
            g.add((self.uriRef, ONTOIM["hasAddress"], self.hasAddress.uriRef))

        if self.hasPavementType:
            g.add(
                (self.uriRef, ONTOIM["hasPavementType"], self.hasPavementType.uriRef))

        if self.hasRoadCategory:
            g.add(
                (self.uriRef, ONTOIM["hasRoadCategory"], self.hasRoadCategory.uriRef))

        if self.hasRoadContext:
            g.add(
                (self.uriRef, ONTOIM["hasRoadContext"], self.hasRoadContext.uriRef))

        if self.hasRoadSignalPresence:
            g.add(
                (self.uriRef, ONTOIM["hasRoadSignalPresence"], self.hasRoadSignalPresence.uriRef))

        if self.hasRoadType:
            g.add((self.uriRef, ONTOIM["hasRoadType"],
                  self.hasRoadType.uriRef))

        if self.hasRoadbedStatus:
            g.add(
                (self.uriRef, ONTOIM["hasRoadbedStatus"], self.hasRoadbedStatus.uriRef))

        if self.roadName:
            for roadName in self.roadName:
                g.add(
                    (self.uriRef, ONTOIM["roadName"], roadName))



from __future__ import annotations

from typing import TYPE_CHECKING

from ontopia_py.l0.Entity import Entity

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .AccidentCircumstance import AccidentCircumstance


class InvolvedEntity(Entity):
    __type__ = ONTOIM["InvolvedEntity"]

    hasAccidentCircumstance: AccidentCircumstance = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAccidentCircumstance:
            g.add((self.uriRef, ONTOIM["hasAccidentCircumstance"],
                  self.hasAccidentCircumstance.uriRef))



from __future__ import annotations

from ontopia_py.l0.Characteristic import Characteristic

from ..ns import *


class RoadSignalPresence(Characteristic):
    __type__ = ONTOIM["RoadSignalPresence"]



from __future__ import annotations

from ontopia_py.Thing import Thing
from rdflib import URIRef

from ..ns import *


class PlantHealthStatus(Thing):
    __type__ = TI["PlantHealthStatus"]


class Bad(PlantHealthStatus):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Bad"])


class Dead(PlantHealthStatus):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Dead"])


class Fair(PlantHealthStatus):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Fair"])


class Good(PlantHealthStatus):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Good"])


class Stump(PlantHealthStatus):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Stump"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.cpev.Event import Event

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.cov.Organization import Organization
    from rdflib import Graph

    from .Subscriber import Subscriber
    from .Subscribers import Subscribers


class Event(Event):
    __type__ = ONTOIM["Event"]

    hasSubscription: List[Subscriber] = None
    hasSubscribers: List[Subscribers] = None
    isOrganizedBy: List[Organization] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasSubscription:
            for hasSubscription in self.hasSubscription:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscription"], hasSubscription.uriRef))

        if self.hasSubscribers:
            for hasSubscribers in self.hasSubscribers:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscribers"], hasSubscribers.uriRef))
        
        if self.isOrganizedBy:
            for isOrganizedBy in self.isOrganizedBy:
                g.add(
                    (self.uriRef, ONTOIM["isOrganizedBy"], isOrganizedBy.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.EventOrSituation import EventOrSituation

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.mu.Value import Value
    from ontopia_py.ti.TemporalEntity import TemporalEntity
    from rdflib import Graph

    from .PlantHealthStatus import PlantHealthStatus


class PlantStatusInTime(EventOrSituation):
    __type__ = ONTOIM["PlantStatusInTime"]

    hasDiameter: List[Value] = None
    hasHeight: List[Value] = None
    hasTemporalEntity: TemporalEntity = None
    hasHealthStatus: PlantHealthStatus = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasDiameter:
            for hasDiameter in self.hasDiameter:
                g.add((self.uriRef, ONTOIM["hasDiameter"], hasDiameter.uriRef))

        if self.hasHeight:
            for hasHeight in self.hasHeight:
                g.add((self.uriRef, ONTOIM["hasHeight"], hasHeight.uriRef))

        if self.hasTemporalEntity:
            g.add((self.uriRef, TI["hasTemporalEntity"],
                  self.hasTemporalEntity.uriRef))

        if self.hasHealthStatus:
            g.add(
                (self.uriRef, ONTOIM["hasHealthStatus"], self.hasHealthStatus.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.EventOrSituation import EventOrSituation

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Geometry import Geometry
    from rdflib import Graph, Literal

    from .AccidentType import AccidentType
    from .InvolvedEntity import InvolvedEntity
    from .InvolvedObstacle import InvolvedObstacle
    from .InvolvedPerson import InvolvedPerson
    from .InvolvedVehicle import InvolvedVehicle
    from .RevelationUnit import RevelationUnit
    from .Road import Road
    from .WeatherCondition import WeatherCondition


class RoadAccident(EventOrSituation):
    __type__ = ONTOIM["RoadAccident"]

    detectedBy: List[RevelationUnit] = None
    hasInvolvedEntity: List[InvolvedEntity] = None
    hasInvolvedObstacle: List[InvolvedObstacle] = None
    hasInvolvedPerson: List[InvolvedPerson] = None
    hasInvolvedVehicle: List[InvolvedVehicle] = None
    hasWeatherCondition: List[WeatherCondition] = None
    hasGeometry: Geometry
    hasAccidentType: AccidentType = None
    hasRoad: Road = None
    date: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.detectedBy:
            for detectedBy in self.detectedBy:
                g.add((self.uriRef, ONTOIM["detectedBy"], detectedBy.uriRef))

        if self.hasInvolvedEntity:
            for hasInvolvedEntity in self.hasInvolvedEntity:
                g.add(
                    (self.uriRef, ONTOIM["hasInvolvedEntity"], hasInvolvedEntity.uriRef))

        if self.hasInvolvedObstacle:
            for hasInvolvedObstacle in self.hasInvolvedObstacle:
                g.add(
                    (self.uriRef, ONTOIM["hasInvolvedObstacle"], hasInvolvedObstacle.uriRef))

        if self.hasInvolvedPerson:
            for hasInvolvedPerson in self.hasInvolvedPerson:
                g.add(
                    (self.uriRef, ONTOIM["hasInvolvedPerson"], hasInvolvedPerson.uriRef))

        if self.hasInvolvedVehicle:
            for hasInvolvedVehicle in self.hasInvolvedVehicle:
                g.add(
                    (self.uriRef, ONTOIM["hasInvolvedVehicle"], hasInvolvedVehicle.uriRef))

        if self.hasWeatherCondition:
            for hasWeatherCondition in self.hasWeatherCondition:
                g.add(
                    (self.uriRef, ONTOIM["hasWeatherCondition"], hasWeatherCondition.uriRef))

        if self.hasGeometry:
            g.add((self.uriRef, ONTOIM["hasGeometry"],
                  self.hasGeometry.uriRef))

        if self.hasAccidentType:
            g.add((self.uriRef, ONTOIM["hasAccidentType"],
                  self.hasAccidentType.uriRef))

        if self.hasRoad:
            g.add((self.uriRef, ONTOIM["hasRoad"],
                  self.hasRoad.uriRef))

        if self.date:
            g.add((self.uriRef, TI["date"], self.date))



from __future__ import annotations

from ontopia_py.Thing import Thing
from rdflib import URIRef

from ..ns import *


class TouristType(Thing):
    __type__ = TI["TouristType"]


class Arrival(TouristType):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Arrival"])


class Presence(TouristType):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Presence"])



from __future__ import annotations

from ontopia_py.cpev.PublicEvent import PublicEvent

from ..ns import *
from .Event import Event


class PublicEvent(Event, PublicEvent):
    __type__ = ONTOIM["PublicEvent"]



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .DemographicObservation import DemographicObservation

if TYPE_CHECKING:
    from rdflib import Graph

    from .TouristType import TouristType


class Tourists(DemographicObservation):
    __type__ = ONTOIM["Tourists"]

    hasTouristType: TouristType = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasTouristType:
            g.add(
                (self.uriRef, ONTOIM["hasTouristType"], self.hasTouristType.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Activity import Activity

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Feature import Feature
    from ontopia_py.mu.Value import Value
    from ontopia_py.ti.TemporalEntity import TemporalEntity
    from rdflib import Graph

    from .WasteCategory import WasteCategory


class WasteProduction(Activity):
    __type__ = ONTOIM["WasteProduction"]

    hasValue: List[Value] = None
    hasTemporalEntity: TemporalEntity = None
    hasSpatialCoverage: Feature = None
    hasWasteCategory: WasteCategory = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasValue:
            for hasValue in self.hasValue:
                g.add((self.uriRef, MU["hasValue"], hasValue.uriRef))

        if self.hasTemporalEntity:
            g.add(
                (self.uriRef, TI["hasTemporalEntity"], self.hasTemporalEntity.uriRef))

        if self.hasSpatialCoverage:
            g.add(
                (self.uriRef, CLV["hasSpatialCoverage"], self.hasSpatialCoverage.uriRef))

        if self.hasWasteCategory:
            g.add(
                (self.uriRef, ONTOIM["hasWasteCategory"], self.hasWasteCategory.uriRef))



from .ns import *
from ontopia_py import createGraph as cg, saveGraph

VERSION = (0, 0, 1)

__author__ = 'Luca Martinelli'
__email__ = 'martinelliluca98@gmail.com'
__version__ = '.'.join(map(str, VERSION))
__description__ = 'A python package to create OntoIM RDFs.'


def createGraph():
    # Create the graph
    g = cg()

    # Ontology
    g.bind("ontoim", ONTOIM)

    # Controlled vocabularies
    g.bind("accidentcircumstances", ACCIDENT_CIRCUMSTANCES)
    g.bind("accidenttypes", ACCIDENT_TYPES)
    g.bind("associationcategories", ASSOCIATION_CATEGORIES)
    g.bind("civilstatuscategories", CIVIL_STATUS_CATEGORIES)
    g.bind("companydemographiccategories", COMPANY_DEMOGRAPHIC_CATEGORIES)
    g.bind("heritagetypes", HERITAGE_TYPES)
    g.bind("involvedpersonstatuses", INVOLVED_PERSON_STATUSES)
    g.bind("landregistrycategories", LAND_REGISTRY_CATEGORIES)
    g.bind("organizationsections", ORGANIZATION_SECTIONS)
    g.bind("pavementtypes", PAVEMENT_TYPES)
    g.bind("revelationunits", REVELATION_UNITS)
    g.bind("roadcategories", ROAD_CATEGORIES)
    g.bind("roadcontexts", ROAD_CONTEXTS)
    g.bind("roadsignalpresencetypes", ROAD_SIGNAL_PRESENCE_TYPES)
    g.bind("roadsignaltypes", ROAD_SIGNAL_TYPES)
    g.bind("roadtypes", ROAD_TYPES)
    g.bind("roadbedtypes", ROADBED_TYPES)
    g.bind("schooltypes", SCHOOL_TYPES)
    g.bind("vehiclecategories", VEHICLE_CATEGORIES)
    g.bind("wastecategories", WASTE_CATEGORIES)
    g.bind("weatherconditions", WEATHER_CONDITIONS)



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.l0.Object import Object

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .CadastralCategory import CadastralCategory


class CadastralData(Object):
    __type__ = ONTOIM["CadastralData"]

    hasCadastralCategory: List[CadastralCategory] = None
    map: Literal = None
    sheet: Literal = None
    subordinate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCadastralCategory:
            g.add(
                (self.uriRef, ONTOIM["hasCadastralCategory"], self.hasCadastralCategory.uriRef))

        if self.hasMembers:
            for hasMembers in self.hasMembers:
                g.add(
                    (self.uriRef, ONTOIM["hasMembers"], hasMembers.uriRef))

        if self.hasReferent:
            for hasReferent in self.hasReferent:
                g.add(
                    (self.uriRef, ONTOIM["hasReferent"], hasReferent.uriRef))

        if self.hasSubscription:
            for hasSubscription in self.hasSubscription:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscription"], hasSubscription.uriRef))

        if self.map:
            g.add((self.uriRef, ONTOIM["map"], self.map))

        if self.sheet:
            g.add((self.uriRef, ONTOIM["sheet"], self.sheet))

        if self.subordinate:
            g.add((self.uriRef, ONTOIM["subordinate"], self.subordinate))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .InvolvedEntity import InvolvedEntity

if TYPE_CHECKING:
    from ontopia_py.cpv.Person import Person
    from rdflib import Graph

    from .InvolvedPersonStatus import InvolvedPersonStatus


class InvolvedPerson(InvolvedEntity):
    __type__ = ONTOIM["InvolvedPerson"]

    hasPerson: InvolvedPersonStatus = None
    hasPerson: Person = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasInvolvedPersonStatus:
            g.add((self.uriRef, ONTOIM["hasInvolvedPersonStatus"],
                  self.hasInvolvedPersonStatus.uriRef))

        if self.hasPerson:
            g.add((self.uriRef, ONTOIM["hasPerson"], self.hasPerson.uriRef))



from __future__ import annotations
from msilib.schema import Feature

from typing import TYPE_CHECKING

from ontopia_py.l0.EventOrSituation import EventOrSituation

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.clv.Feature import Feature
    from ontopia_py.cpv.Person import Person
    from rdflib import Graph, Literal


class DemographicEvent(EventOrSituation):
    __type__ = ONTOIM["DemographicEvent"]

    hasDemographicReference: Person = None
    hasSpatialCoverage: Feature = None
    date: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasDemographicReference:
            g.add((self.uriRef, ONTOIM["hasDemographicReference"],
                  self.hasDemographicReference.uriRef))

        if self.hasSpatialCoverage:
            g.add(
                (self.uriRef, CLV["hasSpatialCoverage"], self.hasSpatialCoverage.uriRef))

        if self.date:
            g.add((self.uriRef, ONTOIM["date"], self.date))



from rdflib import Namespace
from ontopia_py.ns import *

# OntoIM Namespaces

ONTOIM = Namespace("https://w3id.org/ontoim/")

# OntoIM Controlled Vocabularies

ACCIDENT_CIRCUMSTANCES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/accident-circumstances/")
ACCIDENT_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/accident-types/")
ASSOCIATION_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/association-categories/")
CIVIL_STATUS_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/civil-status-categories/")
COMPANY_DEMOGRAPHIC_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/company-demographic-categories/")
HERITAGE_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/heritage-types/")
INVOLVED_PERSON_STATUSES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/involved-person-statuses/")
LAND_REGISTRY_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/land-registry-categories/")
ORGANIZATION_SECTIONS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/organization-sections/")
PAVEMENT_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/pavement-types/")
REVELATION_UNITS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/revelation-units/")
ROAD_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-categories/")
ROAD_CONTEXTS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-contexts/")
ROAD_SIGNAL_PRESENCE_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-signal-presence-types/")
ROAD_SIGNAL_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-signal-types/")
ROAD_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/road-types/")
ROADBED_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/roadbed-types/")
SCHOOL_TYPES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/school-types/")
VEHICLE_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/vehicle-categories/")
WASTE_CATEGORIES = Namespace("https://w3od.org/ontoim/controlled-vocabulary/waste-categories/")
WEATHER_CONDITIONS = Namespace("https://w3od.org/ontoim/controlled-vocabulary/weather-conditions/")


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.poi.PointOfInterest import PointOfInterest

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .PlantStatusInTime import PlantStatusInTime


class Plant(PointOfInterest):
    __type__ = ONTOIM["Plant"]

    hasStatusInTime: List[PlantStatusInTime] = None
    commonName: List[Literal] = None
    plantCode: Literal = None
    species: Literal = None
    birthYear: Literal = None
    plantingDate: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasStatusInTime:
            for hasStatusInTime in self.hasStatusInTime:
                g.add(
                    (self.uriRef, ONTOIM["hasStatusInTime"], hasStatusInTime.uriRef))

        if self.commonName:
            for commonName in self.commonName:
                g.add((self.uriRef, ONTOIM["commonName"], commonName))

        if self.plantCode:
            g.add((self.uriRef, ONTOIM["plantCode"], self.plantCode))

        if self.species:
            g.add((self.uriRef, ONTOIM["species"], self.species))

        if self.birthYear:
            g.add((self.uriRef, ONTOIM["birthYear"], self.birthYear))

        if self.plantingDate:
            g.add((self.uriRef, ONTOIM["plantingDate"], self.plantingDate))



from __future__ import annotations

from ontopia_py.Thing import Thing
from rdflib import URIRef

from ..ns import *


class TrafficFlowDirection(Thing):
    __type__ = TI["TrafficFlowDirection"]


class In(TrafficFlowDirection):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["In"])


class Out(TrafficFlowDirection):
    def __init__(self):
        self.uriRef = URIRef(ONTOIM["Out"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.her.AcademicDiscipline import AcademicDiscipline
from ontopia_py.l0.Activity import Activity

from ..ns import *

if TYPE_CHECKING:
    from ontopia_py.pot.PriceSpecification import PriceSpecification
    from ontopia_py.ti.TimeInterval import TimeInterval
    from rdflib import Graph, Literal

    from .Classroom import Classroom
    from .Subscriber import Subscriber
    from .Subscribers import Subscribers


class Course(Activity):
    __type__ = ONTOIM["Course"]

    atTime: List[TimeInterval] = None
    hasPriceSpecification: List[PriceSpecification] = None
    hasSubscribers: List[Subscribers] = None
    hasSubscription: List[Subscriber] = None
    situatedInClassroom: List[Classroom] = None
    name: List[Literal] = None
    description: List[Literal] = None
    courseCode: Literal = None
    durationHours: Literal = None
    hasAcademicDiscipline: List[AcademicDiscipline] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.atTime:
            for atTime in self.atTime:
                g.add((self.uriRef, TI["atTime"], atTime.uriRef))

        if self.hasPriceSpecification:
            for hasPriceSpecification in self.hasPriceSpecification:
                g.add(
                    (self.uriRef, ONTOIM["hasPriceSpecification"], hasPriceSpecification.uriRef))

        if self.hasSubscribers:
            for hasSubscribers in self.hasSubscribers:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscribers"], hasSubscribers.uriRef))

        if self.hasSubscription:
            for hasSubscription in self.hasSubscription:
                g.add(
                    (self.uriRef, ONTOIM["hasSubscription"], hasSubscription.uriRef))

        if self.situatedInClassroom:
            for situatedInClassroom in self.situatedInClassroom:
                g.add(
                    (self.uriRef, ONTOIM["situatedInClassroom"], situatedInClassroom.uriRef))
        
        if self.hasAcademicDiscipline:
            for hasAcademicDiscipline in self.hasAcademicDiscipline:
                g.add(
                    (self.uriRef, HER["hasAcademicDiscipline"], hasAcademicDiscipline.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.courseCode:
            g.add((self.uriRef, ONTOIM["courseCode"], self.courseCode))

        if self.durationHours:
            g.add((self.uriRef, ONTOIM["durationHours"], self.durationHours))



from __future__ import annotations

from ontopia_py.cis.CulturalEvent import CulturalEvent

from ..ns import *
from .PublicEvent import PublicEvent


class CulturalEvent(CulturalEvent, PublicEvent):
    __type__ = ONTOIM["CulturalEvent"]



from .AccidentCircumstance import AccidentCircumstance
from .AccidentType import AccidentType
from .Accommodation import Accommodation
from .ArtisanOrganization import ArtisanOrganization
from .Association import Association
from .AssociationCategory import AssociationCategory
from .Booking import Booking
from .Bookings import Bookings
from .CadastralCategory import CadastralCategory
from .CadastralData import CadastralData
from .Citizens import Citizens
from .CivilStatus import CivilStatus
from .CivilStatusCategory import CivilStatusCategory
from .CivilStatusEvent import CivilStatusEvent
from .Classroom import Classroom
from .CompanyDemographicCategory import CompanyDemographicCategory
from .ComprehensiveInstitute import ComprehensiveInstitute
from .Course import Course
from .CulturalEvent import CulturalEvent
from .DemographicEvent import DemographicEvent
from .DemographicObservation import DemographicObservation
from .Employees import Employees
from .Event import Event
from .Facility import Facility
from .GreenZone import GreenZone
from .Heritage import Heritage
from .HeritageType import HeritageType
from .Hospital import Hospital
from .HospitalDepartment import HospitalDepartment
from .InvolvedEntity import InvolvedEntity
from .InvolvedObstacle import InvolvedObstacle
from .InvolvedPerson import InvolvedPerson
from .InvolvedPersonStatus import InvolvedPersonStatus
from .InvolvedVehicle import InvolvedVehicle
from .Members import Members
from .Organization import Organization
from .OrganizationSection import OrganizationSection
from .PavementType import PavementType
from .PhysicalClassroom import PhysicalClassroom
from .Plant import Plant
from .PlantHealthStatus import PlantHealthStatus
from .PlantStatusInTime import PlantStatusInTime
from .PrivateHospital import PrivateHospital
from .PrivateOrganization import PrivateOrganization
from .PrivateSchool import PrivateSchool
from .PublicEvent import PublicEvent
from .PublicHospital import PublicHospital
from .PublicSchool import PublicSchool
from .RevelationUnit import RevelationUnit
from .Road import Road
from .RoadAccident import RoadAccident
from .RoadbedStatus import RoadbedStatus
from .RoadCategory import RoadCategory
from .RoadContext import RoadContext
from .RoadSegment import RoadSegment
from .RoadSignal import RoadSignal
from .RoadSignalPresence import RoadSignalPresence
from .RoadSignalType import RoadSignalType
from .RoadType import RoadType
from .School import School
from .SchoolType import SchoolType
from .Subscriber import Subscriber
from .Subscribers import Subscribers
from .Tourists import Tourists
from .TouristType import TouristType
from .TrafficFlow import TrafficFlow
from .TrafficFlowDirection import TrafficFlowDirection
from .Vehicle import Vehicle
from .VehicleCategory import VehicleCategory
from .VideoCommunicationService import VideoCommunicationService
from .VirtualClassroom import VirtualClassroom
from .WasteCategory import WasteCategory
from .WasteProduction import WasteProduction
from .WeatherCondition import WeatherCondition


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ontopia_py.iot.TrafficFlow import TrafficFlow

from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .TrafficFlowDirection import TrafficFlowDirection
    from .VehicleCategory import VehicleCategory


class TrafficFlow(TrafficFlow):
    __type__ = ONTOIM["TrafficFlow"]

    hasTrafficFlowDirection: TrafficFlowDirection = None
    hasVehicleCategory: List[VehicleCategory] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasTrafficFlowDirection:
            g.add((self.uriRef, ONTOIM["hasTrafficFlowDirection"],
                  self.hasTrafficFlowDirection.uriRef))

        if self.hasVehicleCategory:
            for hasVehicleCategory in self.hasVehicleCategory:
                g.add(
                    (self.uriRef, ONTOIM["hasVehicleCategory"], hasVehicleCategory.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .InvolvedEntity import InvolvedEntity

if TYPE_CHECKING:
    from rdflib import Graph

    from .InvolvedPerson import InvolvedPerson
    from .Vehicle import Vehicle


class InvolvedVehicle(InvolvedEntity):
    __type__ = ONTOIM["InvolvedVehicle"]

    hasBackPassenger: List[InvolvedPerson] = None
    hasFrontPassenger: List[InvolvedPerson] = None
    hasPassenger: List[InvolvedPerson] = None
    hasConducent: InvolvedPerson = None
    hasVehicle: Vehicle = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasConducent:
            g.add((self.uriRef, ONTOIM["hasConducent"],
                  self.hasConducent.uriRef))

        if self.hasVehicle:
            g.add((self.uriRef, ONTOIM["hasVehicle"], self.hasVehicle.uriRef))

        if self.hasBackPassenger:
            for hasBackPassenger in self.hasBackPassenger:
                g.add(
                    (self.uriRef, ONTOIM["hasBackPassenger"], hasBackPassenger.uriRef))

        if self.hasFrontPassenger:
            for hasFrontPassenger in self.hasFrontPassenger:
                g.add(
                    (self.uriRef, ONTOIM["hasFrontPassenger"], hasFrontPassenger.uriRef))

        if self.hasPassenger:
            for hasPassenger in self.hasPassenger:
                g.add(
                    (self.uriRef, ONTOIM["hasPassenger"], hasPassenger.uriRef))
